@@ -417,7 +417,7 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
 
 
 def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
-        result_fields=()):
+        result_fields=(), translations={}):
     is_overall_search = request.GET.get('is_overall_search', '')
     (fields, class_name, class_name_lower, ajax_url, charfield_exists, \
             datetimefield_exists, booleanfield_exists) = \
@@ -496,6 +496,7 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
     ret_dic['all_id'] = ','.join([str(obj.id) for obj in \
             ret_dic['objects']])
     ret_dic['result_fields'] = result_fields
+    ret_dic['field_names'] = [translations[fn] if fn in translations else fn for fn in result_fields]
     return render(request, 'ajax/get_object_list.html', ret_dic)
     print(dt)
     print('xx', useful_data_available)
